@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.contrib.syndication.views import Feed
 from django.core.urlresolvers import reverse
-from bookmark.models import Bookmark
+from shiori.bookmark.models import Bookmark
 
 
 class LatestEntries(Feed):
